@@ -19,6 +19,8 @@ DXGTable Handler
 ****************
 """
 
+from __future__ import (print_function, unicode_literals)
+
 import os, sys, json, traceback
 import concurrent.futures
 
@@ -26,6 +28,7 @@ import dxpy
 from . import DXDataObject
 from ..exceptions import DXError
 from ..compat import StringIO
+from ..utils import warn
 
 DXGTABLE_HTTP_THREADS = 4
 
@@ -95,6 +98,11 @@ class DXGTable(DXDataObject):
     def set_http_threadpool_size(cls, num_threads):
         cls._http_threadpool_size = num_threads
 
+    @classmethod
+    def _ensure_http_threadpool(cls):
+        if cls._http_threadpool is None:
+            cls._http_threadpool = dxpy.utils.get_futures_threadpool(max_workers=cls._http_threadpool_size)
+
     def __init__(self, dxid=None, project=None, mode=None, request_size=DEFAULT_TABLE_WRITE_REQUEST_SIZE):
         DXDataObject.__init__(self, dxid=dxid, project=project)
         if mode is None:
@@ -137,15 +145,15 @@ class DXGTable(DXDataObject):
         custom auth).
         '''
         if len(self._row_buf) > 0 or (self._string_row_buf != None and self._string_row_buf.tell() > len('{"data": [')) or len(self._http_threadpool_futures) > 0:
-            print >> sys.stderr, "=== WARNING! ==="
-            print >> sys.stderr, "There is still unflushed data in the destructor of a DXGTable object!"
-            print >> sys.stderr, "We will attempt to flush it now, but if an error were to occur, we could not report it back to you."
-            print >> sys.stderr, "Your program could fail to flush the data but appear to succeed."
-            print >> sys.stderr, "Instead, please call flush() or close(), or use the context managed version (e.g., with open_dxgtable(ID, mode='w') as gtable:)"
+            warn("=== WARNING! ===")
+            warn("There is still unflushed data in the destructor of a DXGTable object!")
+            warn("We will attempt to flush it now, but if an error were to occur, we could not report it back to you.")
+            warn("Your program could fail to flush the data but appear to succeed.")
+            warn("Instead, please call flush() or close(), or use the context managed version (e.g., with open_dxgtable(ID, mode='w') as gtable:)")
         try:
             self.flush(multithread=False)
         except Exception as e:
-            print >> sys.stderr, "=== Exception occurred while flushing accumulated row data for %r" % (self._dxid,)
+            warn("=== Exception occurred while flushing accumulated row data for %r" % (self._dxid,))
             traceback.print_exception(*sys.exc_info())
             raise
 
@@ -323,8 +331,8 @@ class DXGTable(DXDataObject):
                 col_names = ['__id__'] + self.get_col_names(**kwargs)
             else:
                 col_names = columns
-        if self._http_threadpool is None:
-            DXGTable._http_threadpool = dxpy.utils.get_futures_threadpool(max_workers=self._http_threadpool_size)
+
+        DXGTable._ensure_http_threadpool()
 
         request_iterator = self._generate_read_requests(start_row=start, end_row=end, columns=columns, **kwargs)
 
@@ -590,7 +598,7 @@ class DXGTable(DXDataObject):
         """
         for column in columns:
             if type(column) is list:
-                print >> sys.stderr, "Warning: passing a list of lists to lexicographic_index() is deprecated, please use lexicographic_index_column instead."
+                warn("Warning: passing a list of lists to lexicographic_index() is deprecated, please use lexicographic_index_column instead.")
 
         return {"name": name, "type": "lexicographic", "columns": columns}
 
@@ -657,8 +665,8 @@ class DXGTable(DXDataObject):
 
     def _async_add_rows_request(self, *args, **kwargs):
         kwargs['always_retry'] = True
-        if self._http_threadpool is None:
-            DXGTable._http_threadpool = dxpy.utils.get_futures_threadpool(max_workers=self._http_threadpool_size)
+
+        DXGTable._ensure_http_threadpool()
 
         while len(self._http_threadpool_futures) >= self._http_threadpool_size:
             future = dxpy.utils.wait_for_a_future(self._http_threadpool_futures)
