@@ -25,6 +25,7 @@ from dxpy.utils.describe import (get_field_from_jbor, get_job_from_jbor, get_ind
 from dxpy.utils.printing import (GREEN, BLUE, BOLD, ENDC, fill)
 from dxpy.utils.resolver import is_localjob_id
 from dxpy.compat import open, str, environ, USING_PYTHON2
+from dxpy.utils import file_load_utils
 
 def exit_with_error(msg):
     '''
@@ -326,8 +327,10 @@ def run_one_entry_point(job_id, function, input_hash, run_spec, depends_on, name
         # Save job input to env vars
         env_path = os.path.join(job_homedir, 'environment')
         with open(env_path, 'w') as fd:
-            # Following code is what is used to generate env vars on the remote worker
-            fd.write("\n".join(["export {k}=( {vlist} )".format(k=k, vlist=" ".join([pipes.quote(vitem if isinstance(vitem, basestring) else json.dumps(vitem)) for vitem in v])) if isinstance(v, list) else "export {k}={v}".format(k=k, v=pipes.quote(v if isinstance(v, basestring) else json.dumps(v))) for k, v in input_hash.items()]))
+            job_input_file = os.path.join(job_homedir, 'job_input.json')
+            var_defs_hash = file_load_utils.gen_bash_vars(job_input_file)
+            for key, val in var_defs_hash.iteritems():
+                fd.write("{}={}\n".format(key, val))
 
     print(BOLD() + 'Logs:' + ENDC())
     start_time = datetime.datetime.now()
